@@ -3,7 +3,7 @@
 #
 #  (C) Paul Evans, 2022 -- leonerd@leonerd.org.uk
 
-package Feature::Compat::Class 0.02;
+package Feature::Compat::Class 0.03;
 
 use v5.14;
 use warnings;
@@ -78,9 +78,9 @@ sub import
    }
    else {
       require Object::Pad;
-      Object::Pad->VERSION( '0.69' );
+      Object::Pad->VERSION( '0.70' );
       Object::Pad->import(qw( class method field ADJUST ),
-         ':config(always_strict only_class_attrs=isa no_field_attrs)',
+         ':config(always_strict only_class_attrs=isa no_field_attrs no_adjust_attrs)',
       );
    }
 }
@@ -179,6 +179,9 @@ an C<ADJUST> block to initialise a field:
 
 See also L<Object::Pad/ADJUST>.
 
+Attributes are not supported; in particular the C<:params> attribute of
+C<Object::Pad> v0.70.
+
 =head2 Other Keywords
 
 The following other keywords provided by C<Object::Pad> are not supported here
